package es.uca.xmleye.gui.l10n;

/*
 Copyright (C) 2005-2008 Antonio García Domínguez

 This program is free software; you can redistribute it 
 and/or modify it under the terms of the GNU General Public 
 License as published by the Free Software Foundation; 
 either version 2 of the License, or (at your option) any 
 later version.

 This program is distributed in the hope that it will be 
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE. See the GNU General Public License for more 
 details.

 You should have received a copy of the GNU General Public 
 License along with this program; if not, write to the Free 
 Software Foundation, Inc., 59 Temple Place, Suite 330, 
 Boston, MA 02111-1307 USA
 */

import java.util.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * Default locale information (English) for
 * {@link es.uca.xmleye.gui.WndMain}.
 */
public class ResWndMain extends ListResourceBundle {
	public Object[][] getContents() {
		return contents;
	}

	/**
	 * All objects are labeled according to their abstract type:
	 * 
	 * _m -> Mnemonics for the menu element (int) 
	 * _a -> Keyboard shortcuts from the main window (KeyStroke) 
	 * _d -> Description 
	 * _i -> 16x16 icon (png) 
	 * _ibig -> 32x32 icon (png)
	 */
	private static Object[][] contents = {
			{ "menu_file", "File" },
			{ "menu_file_m", new Integer(KeyEvent.VK_F) },
			{ "menu_file_d", "Open files, exit the program, and so on" },
			{ "menu_browse", "Browse" },
			{ "menu_browse_m", new Integer(KeyEvent.VK_B) },
			{ "menu_browse_d",
					"Move around the document" },
			{ "menu_preferences", "Preferences" },
			{ "menu_preferences_m", new Integer(KeyEvent.VK_P) },
			{ "menu_preferences_d", "Set program options" },
			{ "menu_help", "Help" },
			{ "menu_help_m", new Integer(KeyEvent.VK_H) },
			{ "menu_help_d",
					"Shows information about the application and how to use it" },

			// Main Toolbar
			{ "toolbar_main_title", "Main toolbar" },

			// Document list icons
			{ "icon_close_selected", "icons/16x16/close-doc-selected.png" },
			{ "icon_close_unselected", "icons/16x16/close-doc-unselected.png" },

			// File Menu
			
			// Available actions
			{ "action_open", "Open..." },
			{ "action_open_d", "Opens an existing document." },
			{ "action_open_i", "icons/16x16/document-open.png" },
			{ "action_open_ibig", "icons/32x32/document-open.png" },
			{ "action_open_m", new Integer(KeyEvent.VK_O) },
			{ "action_open_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_O, InputEvent.CTRL_MASK) },

			// It doesn't require an icon, as it's not part of the main toolbar
			{ "action_about", "About..." },
			{ "action_about_d", "Shows information about this application." },
			{ "action_about_m", new Integer(KeyEvent.VK_B) },
			{
					"action_about_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_F1,
							InputEvent.SHIFT_MASK) },

			{ "action_toggleautoimport", "Automatic updates" },
			{ "action_toggleautoimport_d",
					"Toggles automatic updates upon changes in the source files." },
			{ "action_toggleautoimport_m", new Integer(KeyEvent.VK_U) },

			{ "action_close", "Close" },
			{ "action_close_d", "Closes the current document." },
			{ "action_close_m", new Integer(KeyEvent.VK_C) },
			{ "action_close_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_W, InputEvent.CTRL_MASK) },

			{ "action_editformats", "Known document formats..." },
			{ "action_editformats_d",
					"Customize settings for all known document formats." },
			{ "action_editformats_m", new Integer(KeyEvent.VK_T) },
			{ "action_editformats_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_T, InputEvent.ALT_MASK) },

			{ "action_expand", "Expand all" },
			{ "action_expand_d", "Expands all tree nodes." },
			{ "action_expand_m", new Integer(KeyEvent.VK_X) },
			{
					"action_expand_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_PLUS,
							InputEvent.ALT_MASK) },

			{ "action_collapse", "Collapse all" },
			{ "action_collapse_d", "Collapses all tree nodes." },
			{ "action_collapse_m", new Integer(KeyEvent.VK_L) },
			{
					"action_collapse_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_MINUS,
							InputEvent.ALT_MASK) },

			{ "action_find", "Find..." },
			{ "action_find_d", "Finds a substring in the XML document." },
			{ "action_find_i", "icons/16x16/edit-find.png" },
			{ "action_find_ibig", "icons/32x32/edit-find.png" },
			{ "action_find_m", new Integer(KeyEvent.VK_F) },
			{ "action_find_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_F, InputEvent.CTRL_MASK) },

			{ "action_findnext", "Find Next" },
			{ "action_findnext_d",
					"Finds the next match from a previous search, or cycles back to the first match." },
			{ "action_findnext_m", new Integer(KeyEvent.VK_N) },
			{ "action_findnext_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_G, InputEvent.CTRL_MASK) },

			{ "action_edit", "Edit Source" },
			{ "action_edit_d", "Opens the current document's source with the editor specified in its document format descriptor." },
			{ "action_edit_i", "icons/16x16/launch-editor.png" },
			{ "action_edit_ibig", "icons/32x32/launch-editor.png" },
			{ "action_edit_m", new Integer(KeyEvent.VK_E) },
			{ "action_edit_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_E, InputEvent.CTRL_MASK) },

			{ "action_parent", "Parent" },
			{ "action_parent_d",
					"Selects the current node's parent node, if any." },
			{ "action_parent_i", "icons/16x16/go-up.png" },
			{ "action_parent_ibig", "icons/32x32/go-up.png" },
			{ "action_parent_m", new Integer(KeyEvent.VK_P) },
			{ "action_parent_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_UP, InputEvent.ALT_MASK) },

			{ "action_child", "First Child" },
			{ "action_child_d",
					"Selects the current node's first child, if any." },
			{ "action_child_i", "icons/16x16/go-down.png" },
			{ "action_child_ibig", "icons/32x32/go-down.png" },
			{ "action_child_m", new Integer(KeyEvent.VK_C) },
			{
					"action_child_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_DOWN,
							InputEvent.ALT_MASK) },

			{ "action_prevsibling", "Previous Sibling" },
			{ "action_prevsibling_d",
					"Selects the current node's previous sibling, if any." },
			{ "action_prevsibling_i", "icons/16x16/go-previous.png" },
			{ "action_prevsibling_ibig", "icons/32x32/go-previous.png" },
			{ "action_prevsibling_m", new Integer(KeyEvent.VK_R) },
			{
					"action_prevsibling_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_LEFT,
							InputEvent.ALT_MASK) },

			{ "action_nextsibling", "Next Sibling" },
			{ "action_nextsibling_d",
					"Selects the current node's next sibling, if any." },
			{ "action_nextsibling_i", "icons/16x16/go-next.png" },
			{ "action_nextsibling_ibig", "icons/32x32/go-next.png" },
			{ "action_nextsibling_m", new Integer(KeyEvent.VK_X) },
			{
					"action_nextsibling_a",
					KeyStroke.getKeyStroke(KeyEvent.VK_RIGHT,
							InputEvent.ALT_MASK) },

			{ "action_selectstylesheet_view", "View" },
			{ "action_selectstylesheet_view_d",
					"Selects the stylesheet to be used for generating node views." },
			{ "action_selectstylesheet_view_m", new Integer(KeyEvent.VK_V) },

			{ "action_selectstylesheet_preproc", "Preprocessing" },
			{ "action_selectstylesheet_preproc_d",
					"Selects the stylesheet to be used for preprocessing the document tree." },
			{ "action_selectstylesheet_preproc_m", new Integer(KeyEvent.VK_P) },

			{ "action_exit", "Quit" },
			{ "action_exit_d", "Quits the program." },
			{ "action_exit_i", "icons/16x16/system-log-out.png" },
			{ "action_exit_ibig", "icons/32x32/system-log-out.png" },
			{ "action_exit_m", new Integer(KeyEvent.VK_Q) },
			/* action_exit_a left empty on purpose */

			{ "action_close_d", "Close" },
			{ "action_closeall_d", "Close All" },

			// Miscellaneous strings
			{ "confirm_exit_msg", "Are you sure you want to quit?" },
			{ "confirm_exit_title", "Quit?" },

			// Status messages (the GUI only knows about the default Ready status)
			{ "status_ready", "Ready" },

	};

	// Test code
	public static void main(String[] args) {

		// Print all values
		for (int i = 0; i < contents.length; ++i) {
			System.out.println(contents[i][0] + " = " + contents[i][1]);
		}

		// Let's try extracting them
		ResourceBundle rb = ResourceBundle.getBundle(
				"es.uca.xmleye.ResVentanaPrincipal", Locale.getDefault());
		for (int i = 0; i < contents.length; ++i) {
			System.out.println(contents[i][0] + " = "
					+ rb.getObject((String) contents[i][0]));
		}
	}
}
